==> nextcloud-25.0.12.tgz: nextcloud/apps/logreader/l10n/it.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Registrazione",
    "Log Reader" : "Lettore dei log",
    "A log reader for Nextcloud" : "Un lettore di log per Nextcloud",
    "Log reader for Nextcloud" : "Lettore di log per Nextcloud",
    "Log reader" : "Lettore dei log",
    "Open log reader settings" : "Apri impostazioni lettore dei log",
    "Log reader settings" : "Impostazioni lettore dei log",
    "Currently the log file {file} is shown" : "Viene attualmente mostrato il file di log {file}",
    "Show server log" : "Mostra log del server",
    "Live view is disabled" : "La visualizzazione in tempo reale è disattivata",
    "No log file" : "Nessun file di log",
    "File-based logging must be enabled to access logs from the Web UI." : "La registrazione basata su file deve essere attivata per accedere ai log dall'interfaccia utente web.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Se pensi si tratti di un errore, verifica {setting} nel tuo {config} e controlla il manuale di amministrazione di Nextcloud.",
    "Level" : "Livello",
    "App" : "Applicazione",
    "No app in context" : "Nessuna app nel contesto",
    "Time" : "Ora",
    "Copy raw entry" : "Copia voce grezza",
    "Copy formatted entry" : "Copia voce formattata",
    "Hide exception details" : "Nascondi dettagli eccezione",
    "View exception details" : "Vedi dettagli eccezione",
    "Raw log entry" : "Voce del log grezza",
    "Log entry successfully copied" : "Voce del log copiata correttamente",
    "Search log entries" : "Cerca voci del log",
    "Caused by {exception}" : "Causato da {exception}",
    "line {line}" : "riga {line}",
    "Filter log levels" : "Filtra livelli di log",
    "Time format" : "Formato orario",
    "Live view" : "Visualizzazione in tempo reale",
    "Download / Upload logs" : "Log di download / upload",
    "Download logs" : "Scarica i log",
    "Show local log file" : "Mostra file di log locale",
    "Upload local log file to be displayed" : "Carica file di log locale da mostrare",
    "Raw data" : "Dati grezzi",
    "Local time" : "Ora locale",
    "UTC time" : "Ora UTC",
    "Time format used for displaying the timestamp" : "Formato da usare per data e ora",
    "(Local log files only support the \"raw\" time format)" : "(I file di log locali supportano solo il formato orario \"grezzo\")",
    "Could not change date time format." : "Impossibile modificare il formato di data e ora.",
    "Polling is disabled because server is not configured to log to file" : "Il polling è disattivato perché il server non è configurato per registrare su file",
    "Polling (live view)" : "Polling (visual. in tempo reale)",
    "Could not change live view setting." : "Impossibile modificare l'impostazione di visualizzazione in tempo reale.",
    "Filter logging levels" : "Filtra livelli di log",
    "Could not set logging levels to show" : "Impossibile impostare i livelli di log da mostrare",
    "Application" : "Applicazione",
    "Message" : "Messaggio",
    "Log entry actions" : "Azioni della voce del log",
    "Loading older log entries" : "Caricamento vecchie voci del log",
    "No older log entries available" : "Non sono disponibili voci del log più vecchie",
    "Collapse row" : "Contrai riga",
    "Expand row" : "Espandi riga",
    "Show details" : "Mostra dettagli",
    "Debug" : "Debug",
    "Info" : "Info",
    "Warning" : "Avviso",
    "Error" : "Errore",
    "Fatal" : "Fatale",
    "Could not fetch new log entries (server unavailable)" : "Impossibile recuperare nuove voci del log (server non disponibile)",
    "Could not fetch new entries" : "Impossibile recuperare nuove voci",
    "Could not copy to clipboard, please copy manually:" : "Impossibile copiare negli appunti, copialo a mano:",
    "\tfrom {address} by {user} at {time}\n" : "\tdal {address} da {user} alle {time}\n",
    "Error parsing log" : "Errore durante l'elaborazione dei log",
    "Caused by " : "Generato da",
    "Copy" : "Copia",
    "Copy raw" : "Copia grezza",
    "Copy formatted" : "Copia formattata",
    "No server logs" : "Nessun log del server",
    "One or more entries are hidden by the log level filter" : "Una o più voci sono nascoste dal filtro del livello di registrazione",
    "Everything is working fine" : "Tutto funziona correttamente",
    "Load log file" : "Carica file di log",
    "Invalid log file" : "File di log non valido",
    "Log levels" : "Livelli di log",
    "Log content" : "Contenuto dei log",
    "Live update" : "Aggiornamento in diretta"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-27.1.7p0.tgz: nextcloud/apps/logreader/l10n/it.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Registrazione",
    "Errors in the log" : "Errori nel registro",
    "No errors in the logs since %s" : "Nessun errore nei registri dal %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n errore nei registri dal %s","%n errori nei registri dal %s","%n errori nei registri dal %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n avviso nei registri dal %s","%n avvisi nei registri dal %s","%n avvisi nei registri dal %s"],
    "Log Reader" : "Lettore dei log",
    "A log reader for Nextcloud" : "Un lettore di log per Nextcloud",
    "Log reader for Nextcloud" : "Lettore di log per Nextcloud",
    "Log reader" : "Lettore dei log",
    "Open log reader settings" : "Apri impostazioni lettore dei log",
    "Log reader settings" : "Impostazioni lettore dei log",
    "Currently the log file {file} is shown" : "Viene attualmente mostrato il file di log {file}",
    "Show server log" : "Mostra log del server",
    "Live view is disabled" : "La visualizzazione in tempo reale è disattivata",
    "No log file" : "Nessun file di log",
    "File-based logging must be enabled to access logs from the Web UI." : "La registrazione basata su file deve essere attivata per accedere ai log dall'interfaccia utente web.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Se pensi si tratti di un errore, verifica {setting} nel tuo {config} e controlla il manuale di amministrazione di Nextcloud.",
    "Level" : "Livello",
    "App" : "Applicazione",
    "No app in context" : "Nessuna app nel contesto",
    "Time" : "Ora",
    "Copy raw entry" : "Copia voce grezza",
    "Copy formatted entry" : "Copia voce formattata",
    "Hide exception details" : "Nascondi dettagli eccezione",
    "View exception details" : "Vedi dettagli eccezione",
    "Raw log entry" : "Voce del log grezza",
    "Log entry successfully copied" : "Voce del log copiata correttamente",
    "Search log entries" : "Cerca voci del log",
    "Caused by {exception}" : "Causato da {exception}",
    "Line {line}" : "Riga {line}",
    "Filter log levels" : "Filtra livelli di log",
    "Set log level" : "Imposta il livello del log",
    "Time format" : "Formato orario",
    "Live view" : "Visualizzazione in tempo reale",
    "Download/Upload logs" : "Registri di Download/Upload",
    "Download logs" : "Scarica i log",
    "Show local log file" : "Mostra file di log locale",
    "Upload local log file to be displayed" : "Carica file di log locale da mostrare",
    "Ctrl" : "Ctrl",
    "Raw data" : "Dati grezzi",
    "Local time" : "Ora locale",
    "UTC time" : "Ora UTC",
    "Time format used for displaying the timestamp" : "Formato da usare per data e ora",
    "(Local log files only support the \"raw\" time format)" : "(I file di log locali supportano solo il formato orario \"grezzo\")",
    "Could not change date time format." : "Impossibile modificare il formato di data e ora.",
    "Polling is disabled because server is not configured to log to file" : "Il polling è disattivato perché il server non è configurato per registrare su file",
    "Polling (live view)" : "Polling (visual. in tempo reale)",
    "Could not change live view setting." : "Impossibile modificare l'impostazione di visualizzazione in tempo reale.",
    "Filter logging levels" : "Filtra livelli di log",
    "Could not set logging levels to show" : "Impossibile impostare i livelli di log da mostrare",
    "Set backend loglevel" : "Imposta loglevel del backend",
    "Could not set logging level" : "Impossibile impostare i livelli di log",
    "Application" : "Applicazione",
    "Message" : "Messaggio",
    "Log entry actions" : "Azioni della voce del log",
    "Loading older log entries" : "Caricamento vecchie voci del log",
    "No older log entries available" : "Non sono disponibili voci del log più vecchie",
    "Collapse row" : "Contrai riga",
    "Expand row" : "Espandi riga",
    "Show details" : "Mostra dettagli",
    "Debug" : "Debug",
    "Info" : "Info",
    "Warning" : "Avviso",
    "Error" : "Errore",
    "Fatal" : "Fatale",
    "Could not load log entries" : "Impossibile caricare le voci del registro",
    "Could not fetch new log entries (server unavailable)" : "Impossibile recuperare nuove voci del log (server non disponibile)",
    "Could not fetch new entries" : "Impossibile recuperare nuove voci",
    "Could not copy to clipboard, please copy manually:" : "Impossibile copiare negli appunti, copialo a mano:",
    "\tfrom {address} by {user} at {time}\n" : "\tdal {address} da {user} alle {time}\n",
    "Error parsing log" : "Errore durante l'elaborazione dei log",
    "Caused by " : "Generato da",
    "Copy" : "Copia",
    "Copy raw" : "Copia grezza",
    "Copy formatted" : "Copia formattata",
    "No server logs" : "Nessun log del server",
    "One or more entries are hidden by the log level filter" : "Una o più voci sono nascoste dal filtro del livello di registrazione",
    "Everything is working fine" : "Tutto funziona correttamente",
    "Load log file" : "Carica file di log",
    "Invalid log file" : "File di log non valido",
    "Log levels" : "Livelli di log",
    "Log content" : "Contenuto dei log",
    "Live update" : "Aggiornamento in diretta",
    "line {line}" : "riga {line}",
    "Download / Upload logs" : "Log di download / upload"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
